@@ -10,15 +10,16 @@ from mldock.config_managers.cli import \
     CliConfigureManager
 import mldock.api.predict as predict_request
 from mldock.terminal import \
-    ChoiceWithNumbers, style_dropdown, style_2_level_detail
+    ChoiceWithNumbers, style_dropdown, style_2_level_detail, \
+        ProgressLogger, pretty_build_logs
 from mldock.platform_helpers.mldock import utils as mldock_utils
 from mldock.config_managers.container import MLDockConfigManager
 from mldock.api.local import \
     search_mldock_containers, docker_build, train_model, deploy_model
 
 click.disable_unicode_literals_warning = True
-logger=logging.getLogger('mldock')
-MLDOCK_CONFIG_NAME='mldock.json'
+logger = logging.getLogger('mldock')
+MLDOCK_CONFIG_NAME = 'mldock.json'
 
 @click.group()
 def local():
@@ -27,22 +28,6 @@ def local():
     """
     pass
 
-def pretty_build_logs(line: dict):
-
-    if line is None:
-        return None
-    error = line.get('error', None)
-    errorDetail = line.get('errorDetail', None)
-    if error is not None:
-        logger.error('{}\n{}'.format(error, errorDetail))
-    
-    stream = line.get('stream','')
-
-    if ('Step' in stream) & (':' in stream):
-        logger.info("\n"+stream)
-    else:
-        logger.debug(stream)
-
 @click.command()
 @click.option('--dir', help='Set the working directory for your mldock container.', required=True)
 @click.option('--no-cache', help='builds container from scratch', is_flag=True)
@@ -74,7 +59,12 @@ def build(obj, dir, no_cache, tag, stage):
         mldock_config.get("requirements_dir", "requirements.txt")
     )
 
-    try:
+    with ProgressLogger(
+        group='Stages',
+        text='Retrieving Stages',
+        spinner='dots',
+        on_success='Stages Retrieved'
+    ) as spinner:
         stages = mldock_config.get("stages", None)
 
         if stage is not None:
@@ -82,26 +72,25 @@ def build(obj, dir, no_cache, tag, stage):
 
         if tag is None:
             raise Exception("tag is not valid. Either choose a stage or set a tag manually")
-    except KeyError as exception:
-        logger.error("Stage not found. Either update stages in mldock config or manually set docker tag.")
-        raise
-    except Exception as exception:
-        logger.error(exception)
-        raise
 
     try:
-        logger.info("\nStarting build...\n")
-        docker_build(
-            image_name=image_name,
-            dockerfile_path=dockerfile_path,
-            module_path=module_path,
-            target_dir_name=mldock_config.get("mldock_module_dir", "src"),
-            requirements_file_path=requirements_file_path,
-            no_cache=no_cache,
-            docker_tag=tag,
-            container_platform=platform_name
-        )
-        logger.info("\nBuild Complete! ヽ(´▽`)/\n")
+        with ProgressLogger(group='Build', text='Building', spinner='dots') as spinner:
+            logs = docker_build(
+                image_name=image_name,
+                dockerfile_path=dockerfile_path,
+                module_path=module_path,
+                target_dir_name=mldock_config.get("mldock_module_dir", "src"),
+                requirements_file_path=requirements_file_path,
+                no_cache=no_cache,
+                docker_tag=tag,
+                container_platform=platform_name
+            )
+            for line in logs:
+
+                spinner.info(pretty_build_logs(line=line))
+
+                spinner.start()
+
     except subprocess.CalledProcessError as exception:
         logger.error(exception)
         raise
@@ -117,7 +106,7 @@ def predict(payload, content_type, host):
     """
     Command to execute prediction request against ml endpoint
     """
-    try:
+    with ProgressLogger(group='Predict', text='Running Request', spinner='dots') as spinner:
         if payload is None:
             logger.info("\nPayload cannot be None. Please provide path to payload file.")
         else:
@@ -128,10 +117,6 @@ def predict(payload, content_type, host):
             else:
                 raise Exception("Content-type is not supported.")
             logger.info(pretty_output)
-            logger.info("\nPrediction Complete! ヽ(´▽`)/")
-    except Exception as exception:
-        logger.error(exception)
-        raise
 
 @click.command()
 @click.option('--dir', help='Set the working directory for your mldock container.', required=True)
@@ -171,7 +156,12 @@ def train(obj, dir, params, env_vars, tag, stage):
     platform = mldock_config.get("platform", None)
     container_dir = mldock_config.get("container_dir", None)
 
-    try:
+    with ProgressLogger(
+        group='Stages',
+        text='Retrieving Stages',
+        spinner='dots',
+        on_success='Stages Retrieved'
+    ) as spinner:
         stages = mldock_config.get("stages", None)
 
         if stage is not None:
@@ -179,44 +169,50 @@ def train(obj, dir, params, env_vars, tag, stage):
 
         if tag is None:
             raise Exception("tag is not valid. Either choose a stage or set a tag manually")
-    except KeyError as exception:
-        logger.error("Stage not found. Either update stages in mldock config or manually set docker tag.")
-        sys.exit(-1)
-    except Exception as exception:
-        logger.error(exception)
-        sys.exit(-1)
 
-    project_env_vars = mldock_config.get('environment', {})
+    with ProgressLogger(
+        group='Environment',
+        text='Retrieving Environment Varaiables',
+        spinner='dots',
+        on_success='Environment Ready'
+    ) as spinner:
+        project_env_vars = mldock_config.get('environment', {})
 
-    for env_var in env_vars:
-        key_, value_ = env_var
-        print(key_, value_)
-        project_env_vars.update(
-            {key_: value_}
+        for env_var in env_vars:
+            key_, value_ = env_var
+            project_env_vars.update(
+                {key_: value_}
+            )
+
+        hyperparameters = mldock_config.get('hyperparameters', {})
+
+        # override hyperparameters
+        for param in params:
+            key_, value_ = param
+            hyperparameters.update(
+                {key_: value_}
+            )
+
+        env_vars = mldock_utils.collect_mldock_environment_variables(
+            stage=stage,
+            hyperparameters=hyperparameters,
+            **project_env_vars
         )
 
-    hyperparameters = mldock_config.get('hyperparameters', {})
-
-    # override hyperparameters
-    for param in params:
-        key_, value_ = param
-        print(key_, value_)
-        hyperparameters.update(
-            {key_: value_}
+        config_manager = CliConfigureManager()
+        env_vars.update(
+            config_manager.local.get('environment')
         )
 
-    env_vars = mldock_utils.collect_mldock_environment_variables(
-        stage=stage,
-        hyperparameters=hyperparameters,
-        **project_env_vars
-    )
+    with ProgressLogger(
+        group='Training',
+        text='Running Training',
+        spinner='dots'
+    ) as spinner:
 
-    config_manager = CliConfigureManager()
-    env_vars.update(
-        config_manager.local.get('environment')
-    )
+        spinner.info("Training Environment = {}".format(env_vars))
+        spinner.start()
 
-    try:
         train_model(
             working_dir=dir,
             docker_tag=tag,
@@ -226,16 +222,6 @@ def train(obj, dir, params, env_vars, tag, stage):
             env=env_vars
         )
 
-        logger.info("Local training completed successfully!")
-    except ValueError:
-        logger.error("This is not a mldock directory: {}".format(dir))
-        raise
-    except subprocess.CalledProcessError as exception:
-        logger.error(exception)
-        raise
-    except Exception as exception:
-        logger.error(exception)
-        raise
 
 @click.command()
 @click.option('--dir', help='Set the working directory for your mldock container.', required=True)
@@ -276,7 +262,12 @@ def deploy(obj, dir, params, env_vars, tag, port, stage):
     platform = mldock_config.get("platform", None)
     container_dir = mldock_config.get("container_dir", None)
 
-    try:
+    with ProgressLogger(
+        group='Stages',
+        text='Retrieving Stages',
+        spinner='dots',
+        on_success='Stages Retrieved'
+    ) as spinner:
         stages = mldock_config.get("stages", None)
 
         if stage is not None:
@@ -284,12 +275,6 @@ def deploy(obj, dir, params, env_vars, tag, port, stage):
 
         if tag is None:
             raise Exception("tag is not valid. Either choose a stage or set a tag manually")
-    except KeyError as exception:
-        logger.error("Stage not found. Either update stages in mldock config or manually set docker tag.")
-        sys.exit(-1)
-    except Exception as exception:
-        logger.error(exception)
-        sys.exit(-1)
 
     project_env_vars = mldock_config.get('environment', {})
 
@@ -320,8 +305,14 @@ def deploy(obj, dir, params, env_vars, tag, port, stage):
         config_manager.local.get('environment')
     )
 
-    try:
-        logger.info("Started local deployment at {}...\n".format(port))
+    with ProgressLogger(
+        group='Deploy',
+        text='Deploying model to {} @ localhost'.format(port),
+        spinner='dots'
+    ) as spinner:
+
+        spinner.info("Deployment Environment = {}".format(env_vars))
+        spinner.start()
         deploy_model(
             working_dir=dir,
             docker_tag=tag,
@@ -332,16 +323,6 @@ def deploy(obj, dir, params, env_vars, tag, port, stage):
             env=env_vars
         )
 
-    except ValueError:
-        logger.error("This is not a mldock directory: {}".format(dir))
-        raise
-    except subprocess.CalledProcessError as exception:
-        logger.error(exception)
-        raise
-    except Exception as exception:
-        logger.error(exception)
-        raise
-
 @click.command()
 def stop():
     """
