@@ -517,7 +517,7 @@ class Environment(mapping.MappingMixin):  # pylint:disable=too-many-public-metho
             hyperparameters_file_dir
         )
 
-        updated_hparams = self.environment_variables.json('MLDOCK_HYPERPARAMETERS')
+        updated_hparams = self.environment_variables.json('MLDOCK_HYPERPARAMETERS', '{}')
 
         hyperparameters.update(
             updated_hparams
