@@ -1,4 +1,8 @@
 import logging
+from pathlib import Path
+import pandas as pd
+from sklearn import datasets
+
 from mldock.platform_helpers.mldock.configuration.environment.base import BaseEnvironment
 from mldock.platform_helpers.mldock.configuration.container import \
     BaseTrainingContainer, BaseServingContainer
@@ -18,7 +22,19 @@ environment = BaseEnvironment(base_dir='/opt/ml/')
 #   - Environment and importing from here to other scripts
 class TrainingContainer(BaseTrainingContainer):
     """Implements the base training container, allow a user to override/add/extend any training container setup logic"""
-    pass
+    
+    def startup(self):
+
+        super(TrainingContainer, self).startup()
+        # in 'dev' we can add the following
+        if self.environment.environment_variables('MLDOCK_STAGE', default=None) == "dev":
+
+            # download data
+            iris = datasets.load_iris(as_frame=True)
+            X = iris.data
+            y = iris.target
+            # write data to iris input data channel
+            pd.concat([X, y], axis=1).to_csv(Path(self.environment.input_data_dir,'iris/train.csv'), index=False)
 
 # (TODO)
 # Assess situations and likelihood of whether users should by
